@@ -1,4 +1,4 @@
-# Copyright © 2012-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -29,6 +29,7 @@ import email.utils
 import heapq
 import os
 import re
+import types
 import urllib.parse
 
 import polib
@@ -183,7 +184,7 @@ class Checker(object, metaclass=abc.ABCMeta):
                 )
                 # pylint: enable=no-member
                 broken_encoding = True
-        ctx = misc.Namespace()
+        ctx = types.SimpleNamespace()
         ctx.file = file
         ctx.is_template = is_template
         ctx.is_binary = is_binary
@@ -603,7 +604,7 @@ class Checker(object, metaclass=abc.ABCMeta):
                     continue
                 if 'T' in date and is_publican:
                     # Publican uses DateTime->now(), which uses the UTC timezone by default:
-                    # https://sources.debian.net/src/publican/2.8-3/lib/Publican/Translate.pm/?hl=748#L744
+                    # https://sources.debian.org/src/publican/2.8-3/lib/Publican/Translate.pm/?hl=748#L744
                     # https://bugs.debian.org/714739
                     tz_hint = '-0000'
                 else:
@@ -879,7 +880,7 @@ class Checker(object, metaclass=abc.ABCMeta):
                 self.tag('empty-file')
 
     def _check_message_flags(self, message):
-        info = misc.Namespace()
+        info = types.SimpleNamespace()
         info.fuzzy = False
         info.range_min = 0
         info.range_max = 1e999  # +inf
