@@ -24,6 +24,7 @@ C integer expressions
 
 import ast
 import functools
+import types
 
 import rply
 import rply.errors
@@ -31,7 +32,7 @@ import rply.errors
 LexingError = rply.errors.LexingError
 ParsingError = rply.errors.ParsingError
 
-# http://git.savannah.gnu.org/cgit/gettext.git/tree/gettext-runtime/intl/plural.y?id=v0.18.3#n132
+# https://git.savannah.gnu.org/cgit/gettext.git/tree/gettext-runtime/intl/plural.y?id=v0.18.3#n132
 
 @functools.lru_cache(maxsize=None)
 def create_lexer():
@@ -157,7 +158,7 @@ from lib import misc  # pylint: disable=wrong-import-position
 class BaseEvaluator(object):
 
     def __init__(self, node):
-        self._ctxt = misc.Namespace()
+        self._ctxt = types.SimpleNamespace()
         self._node = node
 
     def __call__(self):
