@@ -1,4 +1,4 @@
-# Copyright © 2014-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -54,7 +54,7 @@ _directive_re = re.compile('''
     )
 ''', re.VERBOSE)
 
-def _printable_prefix(s, r=re.compile('[ -\x7e]+')):
+def _printable_prefix(s, r=re.compile('[ -\x7E]+')):
     return r.match(s).group()
 
 class _info:
