@@ -1,4 +1,4 @@
-# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -134,7 +134,7 @@ class Tag(object):
                 getattr(self, '_set_' + k)(v)
             except AttributeError:
                 raise UnknownField(k)
-        self.name, self.severity, self.certainty  # pylint: disable=pointless-statement
+        type({self.name, self.severity, self.certainty})
 
     # pylint: disable=attribute-defined-outside-init
 
