@@ -1,4 +1,4 @@
-# Copyright © 2014-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -46,14 +46,22 @@ def test_INT_MAX():
     with assert_raises(struct.error):
         struct.pack('=i', M.INT_MAX + 1)
 
+def is_glibc():
+    try:
+        os.confstr('CS_GNU_LIBC_VERSION')
+    except (ValueError, OSError):
+        return False
+    return True
+
 def test_NL_ARGMAX():
-    if sys.platform.startswith('linux'):
+    plat = sys.platform
+    if plat.startswith('linux') and is_glibc():
         assert_equal(
             M.NL_ARGMAX,
             os.sysconf('SC_NL_ARGMAX')
         )
     else:
-        raise nose.SkipTest('Linux-specific test')
+        raise nose.SkipTest('Test specific to Linux with glibc')
 
 if mock is not None:
     small_NL_ARGMAX = mock.patch('lib.strformat.c.NL_ARGMAX', 42)
